* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Application Rationalization](https://help.sap.com/docs/leanix/ea/application-rationalization)
  * Step 6: Start the Rationalization Initiative
